@@ -1,6 +1,7 @@
 import urllib.parse
 import datetime
 from datetime import timedelta
+import copy
 import singer
 from singer import metrics, metadata, utils
 from singer import Transformer, should_sync_field, UNIX_MILLISECONDS_INTEGER_DATETIME_PARSING
@@ -11,6 +12,7 @@ LOGGER = singer.get_logger()
 
 LOOKBACK_WINDOW = 7
 DATE_WINDOW_SIZE = 30 # days
+PAGE_SIZE = 100
 
 FIELDS_AVAILABLE_FOR_AD_ANALYTICS_V2 = {
     'actionClicks',
@@ -210,12 +212,11 @@ def sync_endpoint(client,
     # Increase the "start" by the "count" for each batch.
     # Continue until the "start" exceeds the total_records.
     start = 0 # Starting offset value for each batch API call
-    count = endpoint_config.get('count', 100) # Batch size; Number of records per API call, default = 100
     total_records = 0
     page = 1
     params = {
         'start': start,
-        'count': count,
+        'count': PAGE_SIZE,
         **static_params # adds in endpoint specific, sort, filter params
     }
     if bookmark_query_field:
@@ -248,6 +249,8 @@ def sync_endpoint(client,
             LOGGER.info('No transformed_data')
             break # No data results
 
+        pre_singer_transformed_data = copy.deepcopy(transformed_data)
+
         # Process records and get the max_bookmark_value and record_count for the set of records
         max_bookmark_value, record_count = process_records(
             catalog=catalog,
@@ -270,7 +273,7 @@ def sync_endpoint(client,
                                                       child_stream_name)
                 if should_stream:
                     # For each parent record
-                    for record in transformed_data:
+                    for record in pre_singer_transformed_data:
                         i = 0
                         # Set parent_id
                         for id_field in id_fields:
@@ -288,6 +291,9 @@ def sync_endpoint(client,
                             if child_stream_name == 'video_ads' and owner_id is not None:
                                 child_endpoint_config['params']['account'] = account
                                 child_endpoint_config['params']['owner'] = owner
+                            else:
+                                LOGGER.warning("Skipping video_ads call for %s account as reference_organization_id is not found.", account)
+                                continue
                         elif stream_name == 'campaigns':
                             campaign = 'urn:li:sponsoredCampaign:{}'.format(parent_id)
                             if child_stream_name == 'creatives':
@@ -412,6 +418,10 @@ def sync(client, config, catalog, state):
     if 'start_date' in config:
         start_date = config['start_date']
 
+    if config.get("page_size"):
+        global PAGE_SIZE # pylint: disable=global-statement
+        PAGE_SIZE = int(config.get("page_size"))
+
     if config.get('date_window_size'):
         LOGGER.info('Using non-standard date window size of %s', config.get('date_window_size'))
         global DATE_WINDOW_SIZE # pylint: disable=global-statement
@@ -580,7 +590,7 @@ def sync(client, config, catalog, state):
         if should_stream:
             # Add appropriate account_filter query parameters based on account_filter type
             account_filter = endpoint_config.get('account_filter', None)
-            if 'accounts' in config and account_filter is not None:
+            if config.get("accounts") and account_filter is not None:
                 account_list = config['accounts'].replace(" ", "").split(",")
                 for idx, account in enumerate(account_list):
                     if account_filter == 'search_id_values_param':
@@ -730,6 +740,15 @@ def sync_ad_analytics(client, catalog, state, last_datetime, stream_name, path,
             if field not in chunk:
                 chunk.append(field)
 
+    ############### PAGINATION (for these 2 streams) ###############
+    # The Tap requests LinkedIn with one Campaign ID at one time.
+    # 1 Campaign permits 100 Ads
+    # Considering, 1 Ad is active and the existing behaviour of the tap uses 30 Day window size
+    #       and timeGranularity = DAILY(Results grouped by day) we get 30 records in one API response
+    # Considering the maximum permitted size of Ads are created, "3000" records will be returned in an API response.
+    # If “count=100” and records=100 in the API are the same then the next url will be returned and if we hit that URL, 400 error code will be returned.
+    # This case is unreachable because here “count” is 10000 and at maximum only 3000 records will be returned in an API response.
+
     total_records = 0
     while window_end_date <= today:
         responses = []
